package com.ruoyi.project.production.service;

import java.util.List;
import com.ruoyi.project.production.domain.TMonthlyQualityReportS6101;

/**
 * 质量月报S6101Service接口
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
public interface ITMonthlyQualityReportS6101Service 
{
    /**
     * 查询质量月报S6101
     * 
     * @param id 质量月报S6101ID
     * @return 质量月报S6101
     */
    public TMonthlyQualityReportS6101 selectTMonthlyQualityReportS6101ById(Long id);

    /**
     * 查询质量月报S6101列表
     * 
     * @param tMonthlyQualityReportS6101 质量月报S6101
     * @return 质量月报S6101集合
     */
    public List<TMonthlyQualityReportS6101> selectTMonthlyQualityReportS6101List(TMonthlyQualityReportS6101 tMonthlyQualityReportS6101);

    /**
     * 新增质量月报S6101
     * 
     * @param tMonthlyQualityReportS6101 质量月报S6101
     * @return 结果
     */
    public int insertTMonthlyQualityReportS6101(TMonthlyQualityReportS6101 tMonthlyQualityReportS6101);

    /**
     * 修改质量月报S6101
     * 
     * @param tMonthlyQualityReportS6101 质量月报S6101
     * @return 结果
     */
    public int updateTMonthlyQualityReportS6101(TMonthlyQualityReportS6101 tMonthlyQualityReportS6101);

    /**
     * 批量删除质量月报S6101
     * 
     * @param ids 需要删除的质量月报S6101ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS6101ByIds(Long[] ids);

    /**
     * 删除质量月报S6101信息
     * 
     * @param id 质量月报S6101ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS6101ById(Long id);
}
